@@ -36,7 +36,9 @@ class BatchProcessor:
         self.task_filter = re.compile("^([0-9a-z\-_]+(\/[0-9a-z\-_]+)*)$")
         self.last_status_time = None
         self.callables = {}
+        self.callables_params = {}
         self.entry_name = "batch_filter_entrypoint"
+        self.param_name = "batch_filter_parameters"
         if self.config.get("db-hostname", "skip") == "skip":
             logger.warning("Skipping database initialization")
         else:
@@ -165,6 +167,7 @@ class BatchProcessor:
         match = self.task_filter.match(t)
         module_name = None
         entry_method = None
+        param_dict = None
         failure = None
         # Is this a match?
         if match:
@@ -183,6 +186,8 @@ class BatchProcessor:
                                 if not callable(entry_method):
                                     entry_method = None
                                     failure = f"Entrypoint was not callable in filter module {module_filepath}"
+                                if hasattr(module, self.param_name):
+                                    param_dict = getattr(module, self.param_name)
                             else:
                                 failure = f"Filter module {module_filepath} did not have method {self.entry_name}"
                         else:
@@ -195,31 +200,37 @@ class BatchProcessor:
                 failure = f"Could not find filter module {module_filepath}"
         else:
             failure = f"No match for type {t}"
-        return entry_method, failure
+        return entry_method, param_dict, failure
 
     def get_callable_for_type(self, t):
         if t in self.callables:
-            return self.callables.get(t), None
+            return self.callables.get(t), self.callables_params.get(t), None
         else:
-            cb, failure = self.get_callable_for_type_raw(t)
+            cb, params, failure = self.get_callable_for_type_raw(t)
             if cb:
                 self.callables[t] = cb
-            return cb, failure
+            if params:
+                self.callables_params[t] = params
+            return cb, params, failure
 
     def _watchdog_hang_detected(self):
         logger.error("Watchdog triggered exception, restarting batch")
         sys.exit(99)
 
-    def _execute_safely(self, entrypoint, item):
+    def _execute_safely(self, entrypoint, params, item):
         # logger.info("SAFE EXECUTION STARTED!")
         failure = None
         result = None
         try:
-            # We cap runtime at TTL if set or DEFAULT_TTL as default
-            timeout = item.get("ttl_seconds")
-            if not timeout or timeout <= 0:
-                timeout = self.config.get("batch-default-ttl", 30)
-            watchdog = fk.utils.Watchdog.Watchdog(timeout, self._watchdog_hang_detected)
+            # We cap runtime at TTL from which ever is set first; item ttl, param ttl or environment fallback value
+            timeout = self.config.get("batch-default-ttl", 0)
+            timeout = params.get("ttl_seconds", timeout) if params else timeout
+            timeout = item.get("ttl_seconds", timeout) if item else timeout
+            if timeout and timeout > 0:
+                logger.info(f"Using watchdog with ttl={timeout}sec")
+                watchdog = fk.utils.Watchdog.Watchdog(timeout, self._watchdog_hang_detected)
+            else:
+                logger.info(f"No watchdog enabled")
             # logger.info("££££ Entry")
             unpackable = entrypoint(item, self.config)
             try:
@@ -264,13 +275,13 @@ class BatchProcessor:
             t = item.get("type", None)
             updated_at = item.get("updated_at", None)
             if id and t and updated_at:
-                entrypoint, failure = self.get_callable_for_type(t)
+                entrypoint, params, failure = self.get_callable_for_type(t)
                 if entrypoint and failure:
                     entrypoint = None
                     failure = f"{failure} AND ENTRYPOINT WAS SET!"
                 result = None
                 if entrypoint:
-                    result, failure = self._execute_safely(entrypoint, item)
+                    result, failure = self._execute_safely(entrypoint, params, item)
                 if failure:
                     logger.warning("¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤ BATCH FILTER FAILED WITH ¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤")
                     logger.warning(failure)
@@ -293,7 +304,7 @@ class BatchProcessor:
         item = self.db.book_throttled_batch_item(self.db.PENDING, self.db.IN_PROGRESS, self.worker_id)
         if item:
             if self.do_log:
-                logger.info("Processing item:")
+                logger.info("Processing throttled item:")
                 logger.info(pformat(item))
             id = item.get("id", None)
             t = item.get("type", None)
@@ -304,13 +315,13 @@ class BatchProcessor:
                     logger.warning(pformat(item))
                     failure = "Not booked"
                 else:
-                    entrypoint, failure = self.get_callable_for_type(t)
+                    entrypoint, params, failure = self.get_callable_for_type(t)
                     if entrypoint and failure:
                         entrypoint = None
                         failure = f"{failure} AND ENTRYPOINT WAS SET!"
                     result = None
                     if entrypoint:
-                        result, failure = self._execute_safely(entrypoint, item)
+                        result, failure = self._execute_safely(entrypoint, params, item)
                     if failure:
                         logger.warning("¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤ BATCH FILTER FAILED WITH ¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤¤")
                         logger.warning(failure)
